<?php
/**
 * Banner global map file.
 *
 * @package xts
 */

use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Direct access not allowed.
}

if ( ! function_exists( 'cheshalo_get_button_content_general_map' ) ) {
	/**
	 * Get button map.
	 *
	 * @param  object $element  Element object.
	 * @param  array  $custom_args  Custom args.
	 *
	 * @since 1.0.0
	 */
	function cheshalo_get_button_content_general_map( $element, $custom_args = array() ) {
		$default_args = array(
			'link'          => true,
			'smooth_scroll' => true,
			'text'          => 'Read more',
		);

		$args = wp_parse_args( $custom_args, $default_args );

		$element->add_control(
			'text',
			[
				'label'   => esc_html__( 'Text', 'cheshalo' ),
				'type'    => Controls_Manager::TEXT,
				'default' => $args['text'],
			]
		);

		if ( $args['link'] ) {
			$element->add_control(
				'link',
				[
					'label'   => esc_html__( 'Link', 'cheshalo' ),
					'type'    => Controls_Manager::URL,
					'default' => [
						'url'         => '#',
						'is_external' => false,
						'nofollow'    => false,
					],
				]
			);
		}

		if ( $args['smooth_scroll'] ) {
			$element->add_control(
				'button_smooth_scroll',
				[
					'label'        => esc_html__( 'Smooth scroll', 'cheshalo' ),
					'description'  => esc_html__(
						'When you turn on this option you need to specify this button link with a hash symbol. For example #section-id
Then you need to have a section with an ID of "section-id" and this button click will smoothly scroll the page to that section.',
						'cheshalo'
					),
					'type'         => Controls_Manager::SWITCHER,
					'default'      => 'no',
					'label_on'     => esc_html__( 'Yes', 'cheshalo' ),
					'label_off'    => esc_html__( 'No', 'cheshalo' ),
					'return_value' => 'yes',
					'separator'    => 'before',
				]
			);

			$element->add_control(
				'button_smooth_scroll_time',
				[
					'label'     => esc_html__( 'Smooth scroll time (ms)', 'cheshalo' ),
					'type'      => Controls_Manager::NUMBER,
					'default'   => 100,
					'condition' => [
						'button_smooth_scroll' => [ 'yes' ],
					],
				]
			);

			$element->add_control(
				'button_smooth_scroll_offset',
				[
					'label'     => esc_html__( 'Smooth scroll offset (px)', 'cheshalo' ),
					'type'      => Controls_Manager::NUMBER,
					'default'   => 100,
					'condition' => [
						'button_smooth_scroll' => [ 'yes' ],
					],
				]
			);
		}

		$element->add_control(
			'button_collapsible_content',
			array(
				'label'        => esc_html__( 'Use for collapsible content', 'cheshalo' ),
				'description'  => esc_html__( 'Enable this option when you place this button inside the container with the "Collapsible content" option turned on.', 'cheshalo' ),
				'type'         => Controls_Manager::SWITCHER,
				'default'      => '',
				'label_on'     => esc_html__( 'Yes', 'cheshalo' ),
				'label_off'    => esc_html__( 'No', 'cheshalo' ),
				'return_value' => 'yes',
				'separator'    => 'before',
			)
		);
	}
}

if ( ! function_exists( 'cheshalo_get_button_style_general_map' ) ) {
	/**
	 * Get button map.
	 *
	 * @param  object $element  Element object.
	 *
	 * @since 1.0.0
	 */
	function cheshalo_get_button_style_general_map( $element ) {
		$element->add_control(
			'style',
			[
				'label'   => esc_html__( 'Style', 'cheshalo' ),
				'type'    => Controls_Manager::SELECT,
				'options' => [
					'default'  => esc_html__( 'Flat', 'cheshalo' ),
					'bordered' => esc_html__( 'Bordered', 'cheshalo' ),
					'link'     => esc_html__( 'Link button', 'cheshalo' ),
					'3d'       => esc_html__( '3D', 'cheshalo' ),
				],
				'default' => 'default',
			]
		);

		$element->add_control(
			'color',
			[
				'label'   => esc_html__( 'Predefined color', 'cheshalo' ),
				'type'    => Controls_Manager::SELECT,
				'options' => [
					'default' => esc_html__( 'Grey', 'cheshalo' ),
					'primary' => esc_html__( 'Primary', 'cheshalo' ),
					'alt'     => esc_html__( 'Alternative', 'cheshalo' ),
					'black'   => esc_html__( 'Black', 'cheshalo' ),
					'white'   => esc_html__( 'White', 'cheshalo' ),
					'custom'  => esc_html__( 'Custom', 'cheshalo' ),
				],
				'default' => 'default',
			]
		);

		$element->start_controls_tabs(
			'button_tabs_style',
			[
				'condition' => [
					'color' => [ 'custom' ],
				],
			]
		);

		$element->start_controls_tab(
			'button_tab_normal',
			[
				'label' => esc_html__( 'Normal', 'cheshalo' ),
			]
		);

		$element->add_control(
			'bg_color',
			[
				'label'     => esc_html__( 'Background color', 'cheshalo' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wd-button-wrapper a' => 'background-color: {{VALUE}}; border-color: {{VALUE}};',
				],
			]
		);

		$element->add_control(
			'color_scheme',
			[
				'label'   => esc_html__( 'Text color scheme', 'cheshalo' ),
				'type'    => Controls_Manager::SELECT,
				'options' => [
					'inherit' => esc_html__( 'Inherit', 'cheshalo' ),
					'dark'    => esc_html__( 'Dark', 'cheshalo' ),
					'light'   => esc_html__( 'Light', 'cheshalo' ),
					'custom'  => esc_html__( 'Custom', 'cheshalo' ),
				],
				'default' => 'inherit',
			]
		);

		$element->add_control(
			'custom_color_scheme',
			[
				'label'     => esc_html__( 'Custom text color', 'cheshalo' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wd-button-wrapper a' => 'color: {{VALUE}};',
				],
				'condition' => array(
					'color_scheme' => 'custom',
				),
			]
		);

		$element->end_controls_tab();

		$element->start_controls_tab(
			'button_tab_hover',
			[
				'label' => esc_html__( 'Hover', 'cheshalo' ),
			]
		);

		$element->add_control(
			'bg_color_hover',
			[
				'label'     => esc_html__( 'Background color hover', 'cheshalo' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wd-button-wrapper:hover a' => 'background-color: {{VALUE}}; border-color: {{VALUE}};',
				],
			]
		);

		$element->add_control(
			'color_scheme_hover',
			[
				'label'   => esc_html__( 'Text color scheme on hover', 'cheshalo' ),
				'type'    => Controls_Manager::SELECT,
				'options' => [
					'inherit' => esc_html__( 'Inherit', 'cheshalo' ),
					'dark'    => esc_html__( 'Dark', 'cheshalo' ),
					'light'   => esc_html__( 'Light', 'cheshalo' ),
					'custom'  => esc_html__( 'Custom', 'cheshalo' ),
				],
				'default' => 'inherit',
			]
		);

		$element->add_control(
			'custom_color_scheme_hover',
			[
				'label'     => esc_html__( 'Custom text color on hover', 'cheshalo' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wd-button-wrapper:hover a' => 'color: {{VALUE}};',
				],
				'condition' => array(
					'color_scheme_hover' => 'custom',
				),
			]
		);

		$element->end_controls_tab();

		$element->end_controls_tabs();

		$element->add_control(
			'size',
			[
				'label'   => esc_html__( 'Predefined size', 'cheshalo' ),
				'type'    => Controls_Manager::SELECT,
				'options' => [
					'default'     => esc_html__( 'Default', 'cheshalo' ),
					'extra-small' => esc_html__( 'Extra Small', 'cheshalo' ),
					'small'       => esc_html__( 'Small', 'cheshalo' ),
					'large'       => esc_html__( 'Large', 'cheshalo' ),
					'extra-large' => esc_html__( 'Extra Large', 'cheshalo' ),
				],
				'default' => 'default',
			]
		);

		$element->add_control(
			'shape',
			[
				'label'   => esc_html__( 'Shape', 'cheshalo' ),
				'type'    => Controls_Manager::SELECT,
				'options' => [
					'rectangle'  => esc_html__( 'Rectangle', 'cheshalo' ),
					'round'      => esc_html__( 'Circle', 'cheshalo' ),
					'semi-round' => esc_html__( 'Round', 'cheshalo' ),
				],
				'condition' => [
					'style!' => [ 'link' ],
				],
				'default' => 'rectangle',
			]
		);
	}
}

if ( ! function_exists( 'cheshalo_get_button_style_icon_map' ) ) {
	/**
	 * Get button map.
	 *
	 * @param  object $element  Element object.
	 *
	 * @since 1.0.0
	 */
	function cheshalo_get_button_style_icon_map( $element ) {
		$element->add_control(
			'icon',
			[
				'label' => esc_html__( 'Icon', 'cheshalo' ),
				'type'  => Controls_Manager::ICONS,
			]
		);

		$element->add_control(
			'icon_position',
			[
				'label'   => esc_html__( 'Icon position', 'cheshalo' ),
				'type'    => Controls_Manager::SELECT,
				'options' => [
					'right' => esc_html__( 'Right', 'cheshalo' ),
					'left'  => esc_html__( 'Left', 'cheshalo' ),
				],
				'default' => 'right',
			]
		);
	}
}

if ( ! function_exists( 'cheshalo_get_button_style_layout_map' ) ) {
	/**
	 * Get button map.
	 *
	 * @param  object $element  Element object.
	 *
	 * @since 1.0.0
	 */
	function cheshalo_get_button_style_layout_map( $element ) {
		$element->add_control(
			'align',
			[
				'label'   => esc_html__( 'Align', 'cheshalo' ),
				'type'    => 'wd_buttons',
				'options' => [
					'left'   => [
						'title' => esc_html__( 'Left', 'cheshalo' ),
						'image' => CHESHALO_ASSETS_IMAGES . '/settings/align/left.jpg',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'cheshalo' ),
						'image' => CHESHALO_ASSETS_IMAGES . '/settings/align/center.jpg',
					],
					'right'  => [
						'title' => esc_html__( 'Right', 'cheshalo' ),
						'image' => CHESHALO_ASSETS_IMAGES . '/settings/align/right.jpg',
					],
				],
				'default' => 'center',
			]
		);

		$element->add_control(
			'full_width',
			[
				'label'        => esc_html__( 'Full width', 'cheshalo' ),
				'type'         => Controls_Manager::SWITCHER,
				'default'      => 'no',
				'label_on'     => esc_html__( 'Yes', 'cheshalo' ),
				'label_off'    => esc_html__( 'No', 'cheshalo' ),
				'return_value' => 'yes',
			]
		);
	}
}
