<?php
/**
 * Title map.
 *
 * @package xts
 */

namespace XTS\Elementor;

use Elementor\Group_Control_Typography;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Plugin;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Direct access not allowed.
}

/**
 * Elementor widget that inserts an embeddable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class Product_Categories extends Widget_Base {
	/**
	 * Get widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'wd_product_categories';
	}

	/**
	 * Get widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Product categories', 'cheshalo' );
	}

	/**
	 * Get widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'wd-icon-product-categories';
	}

	/**
	 * Get widget categories.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'wd-elements' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		/**
		 * Content tab.
		 */

		/**
		 * General settings.
		 */
		$this->start_controls_section(
			'general_content_section',
			[
				'label' => esc_html__( 'General', 'cheshalo' ),
			]
		);

		$this->add_control(
			'css_classes',
			array(
				'type'         => 'wd_css_class',
				'default'      => 'wd-nav-product-cat-wrap',
				'prefix_class' => '',
				'condition'    => array(
					'type' => array( 'navigation' ),
				),
			)
		);

		$this->add_control(
			'data_source',
			[
				'label'   => esc_html__( 'Data source', 'cheshalo' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'custom_query',
				'options' => array(
					'custom_query' => esc_html__( 'Custom query', 'cheshalo' ),
					'wc_query'     => esc_html__( 'Woocommerce query', 'cheshalo' ),
				),
			]
		);

		$this->add_control(
			'type',
			[
				'label'   => esc_html__( 'Type', 'cheshalo' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'grid',
				'options' => array(
					'navigation' => esc_html__( 'Navigation', 'cheshalo' ),
					'grid'       => esc_html__( 'Grid', 'cheshalo' ),
				),
			]
		);

		$this->add_control(
			'images',
			[
				'label'        => esc_html__( 'Enable images', 'cheshalo' ),
				'type'         => Controls_Manager::SWITCHER,
				'default'      => 'yes',
				'label_on'     => esc_html__( 'Yes', 'cheshalo' ),
				'label_off'    => esc_html__( 'No', 'cheshalo' ),
				'return_value' => 'yes',
				'condition'    => [
					'type' => [ 'navigation' ],
				],
			]
		);

		$this->add_control(
			'product_count',
			[
				'label'        => esc_html__( 'Enable product count', 'cheshalo' ),
				'type'         => Controls_Manager::SWITCHER,
				'default'      => 'yes',
				'label_on'     => esc_html__( 'Yes', 'cheshalo' ),
				'label_off'    => esc_html__( 'No', 'cheshalo' ),
				'return_value' => 'yes',
				'condition'    => [
					'type' => [ 'navigation' ],
				],
			]
		);

		$this->add_control(
			'mobile_accordion',
			[
				'label'        => esc_html__( 'Mobile accordion', 'cheshalo' ),
				'type'         => Controls_Manager::SWITCHER,
				'default'      => 'on',
				'label_on'     => esc_html__( 'On', 'cheshalo' ),
				'label_off'    => esc_html__( 'Off', 'cheshalo' ),
				'return_value' => 'on',
				'prefix_class' => 'wd-nav-accordion-mb-',
				'condition'    => [
					'type' => [ 'navigation' ],
				],
			]
		);

		$this->add_control(
			'shop_categories_ancestors',
			[
				'label'        => esc_html__( 'Show current category ancestors', 'cheshalo' ),
				'description'  => esc_html__( 'If you visit category Man, for example, only man\'s subcategories will be shown in the page title like T-shirts, Coats, Shoes etc.', 'cheshalo' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_block'  => true,
				'default'      => 'no',
				'label_on'     => esc_html__( 'Yes', 'cheshalo' ),
				'label_off'    => esc_html__( 'No', 'cheshalo' ),
				'return_value' => 'yes',
				'condition'    => [
					'type'        => [ 'navigation' ],
					'data_source' => [ 'wc_query' ],
				],
			]
		);

		$this->add_control(
			'show_categories_neighbors',
			[
				'label'        => esc_html__( 'Show category neighbors if there is no children', 'cheshalo' ),
				'description'  => esc_html__( 'If the category you visit doesn\'t contain any subcategories, the page title menu will display this category\'s neighbors categories.', 'cheshalo' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_block'  => true,
				'default'      => 'no',
				'label_on'     => esc_html__( 'Yes', 'cheshalo' ),
				'label_off'    => esc_html__( 'No', 'cheshalo' ),
				'return_value' => 'yes',
				'condition'    => [
					'type'        => [ 'navigation' ],
					'data_source' => [ 'wc_query' ],
				],
			]
		);

		$this->add_control(
			'number',
			[
				'label'       => esc_html__( 'Number', 'cheshalo' ),
				'description' => esc_html__( 'Enter the number of categories to display for this element.', 'cheshalo' ),
				'type'        => Controls_Manager::NUMBER,
				'condition'   => [
					'data_source' => [ 'custom_query' ],
				],
			]
		);

		$this->add_control(
			'orderby',
			[
				'label'     => esc_html__( 'Order by', 'cheshalo' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => '',
				'options'   => array(
					''           => '',
					'id'         => esc_html__( 'ID', 'cheshalo' ),
					'date'       => esc_html__( 'Date', 'cheshalo' ),
					'title'      => esc_html__( 'Title', 'cheshalo' ),
					'menu_order' => esc_html__( 'Menu order', 'cheshalo' ),
					'modified'   => esc_html__( 'Last modified date', 'cheshalo' ),
				),
				'condition' => [
					'data_source' => [ 'custom_query' ],
				],
			]
		);

		$this->add_control(
			'order',
			[
				'label'     => esc_html__( 'Sort order', 'cheshalo' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => '',
				'options'   => array(
					''     => esc_html__( 'Inherit', 'cheshalo' ),
					'DESC' => esc_html__( 'Descending', 'cheshalo' ),
					'ASC'  => esc_html__( 'Ascending', 'cheshalo' ),
				),
				'condition' => [
					'data_source' => [ 'custom_query' ],
				],
			]
		);

		$this->add_control(
			'ids',
			[
				'label'       => esc_html__( 'Categories', 'cheshalo' ),
				'description' => esc_html__( 'List of product categories.', 'cheshalo' ),
				'type'        => 'wd_autocomplete',
				'search'      => 'cheshalo_get_taxonomies_by_query',
				'render'      => 'cheshalo_get_taxonomies_title_by_id',
				'taxonomy'    => 'product_cat',
				'multiple'    => true,
				'label_block' => true,
				'condition'   => [
					'data_source' => [ 'custom_query' ],
				],
			]
		);

		$this->add_control(
			'hide_empty',
			[
				'label'        => esc_html__( 'Hide empty', 'cheshalo' ),
				'description'  => esc_html__( 'Don’t display categories that don’t have any products assigned.', 'cheshalo' ),
				'type'         => Controls_Manager::SWITCHER,
				'default'      => 'yes',
				'label_on'     => esc_html__( 'Yes', 'cheshalo' ),
				'label_off'    => esc_html__( 'No', 'cheshalo' ),
				'return_value' => 'yes',
			]
		);

		$this->end_controls_section();

		/**
		 * Style tab.
		 */

		/**
		 * Design settings.
		 */
		$this->start_controls_section(
			'design_style_section',
			[
				'label' => esc_html__( 'Design', 'cheshalo' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'categories_design',
			[
				'label'       => esc_html__( 'Categories design', 'cheshalo' ),
				'description' => esc_html__( 'Overrides option from Theme Settings -> Shop', 'cheshalo' ),
				'type'        => Controls_Manager::SELECT,
				'default'     => 'inherit',
				'options'     => array(
					'inherit'       => esc_html__( 'Inherit from Theme Settings', 'cheshalo' ),
					'default'       => esc_html__( 'Default', 'cheshalo' ),
					'alt'           => esc_html__( 'Alternative', 'cheshalo' ),
					'center'        => esc_html__( 'Center title', 'cheshalo' ),
					'replace-title' => esc_html__( 'Replace title', 'cheshalo' ),
					'mask-subcat'   => esc_html__( 'Mask with subcategories', 'cheshalo' ),
				),
				'condition'   => [
					'type' => [ 'grid' ],
				],
			]
		);

		$this->add_control(
			'img_size',
			array(
				'label'     => esc_html__( 'Image size', 'cheshalo' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'large',
				'options'   => cheshalo_get_all_image_sizes_names( 'elementor' ),
				'condition' => [
					'type' => [ 'grid' ],
				],
			)
		);

		$this->add_control(
			'img_size_custom',
			array(
				'label'       => esc_html__( 'Image dimension', 'cheshalo' ),
				'type'        => Controls_Manager::IMAGE_DIMENSIONS,
				'description' => esc_html__( 'You can crop the original image size to any custom size. You can also set a single value for height or width in order to keep the original size ratio.', 'cheshalo' ),
				'condition'   => array(
					'type'     => [ 'grid' ],
					'img_size' => 'custom',
				),
			)
		);

		$this->add_responsive_control(
			'image_container_width',
			array(
				'label'      => esc_html__( 'Image container width', 'cheshalo' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => array( '%', 'px' ),
				'default'    => array(
					'unit' => 'px',
				),
				'range'      => array(
					'px' => array(
						'min'  => 0,
						'max'  => 1000,
						'step' => 1,
					),
					'%'  => array(
						'min'  => 0,
						'max'  => 100,
						'step' => 1,
					),
				),
				'selectors'  => array(
					'{{WRAPPER}}' => '--wd-cat-img-width: {{SIZE}}{{UNIT}};',
				),
				'condition'  => array(
					'categories_design' => array( 'alt' ),
				),
			)
		);

		$this->add_control(
			'color_scheme',
			[
				'label'     => esc_html__( 'Color scheme', 'cheshalo' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'inherit',
				'options'   => array(
					'inherit' => esc_html__( 'Inherit from Theme Settings', 'cheshalo' ),
					'dark'    => esc_html__( 'Dark', 'cheshalo' ),
					'light'   => esc_html__( 'Light', 'cheshalo' ),
				),
				'condition' => [
					'type'              => [ 'grid' ],
					'categories_design' => [ 'default', 'mask-subcat' ],
				],
			]
		);

		$this->add_control(
			'categories_with_shadow',
			[
				'label'     => esc_html__( 'Categories with shadow', 'cheshalo' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => '',
				'options'   => array(
					''        => esc_html__( 'Inherit from Theme Settings', 'cheshalo' ),
					'enable'  => esc_html__( 'Enable', 'cheshalo' ),
					'disable' => esc_html__( 'Disable', 'cheshalo' ),
				),
				'condition' => [
					'type'              => [ 'grid' ],
					'categories_design' => [ 'alt', 'default' ],
				],
			]
		);

		$this->add_control(
			'rounding_size',
			array(
				'label'     => esc_html__( 'Rounding', 'cheshalo' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => array(
					''       => esc_html__( 'Inherit', 'cheshalo' ),
					'0'      => esc_html__( '0', 'cheshalo' ),
					'5'      => esc_html__( '5', 'cheshalo' ),
					'8'      => esc_html__( '8', 'cheshalo' ),
					'12'     => esc_html__( '12', 'cheshalo' ),
					'custom' => esc_html__( 'Custom', 'cheshalo' ),
				),
				'default'   => '',
				'selectors' => array(
					'{{WRAPPER}}' => '--wd-brd-radius: {{VALUE}}px;',
				),
				'condition' => [
					'type' => [ 'grid' ],
				],
			)
		);

		$this->add_control(
			'custom_rounding_size',
			array(
				'label'      => esc_html__( 'Rounding', 'cheshalo' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => array( '%', 'px' ),
				'range'      => array(
					'px' => array(
						'min'  => 1,
						'max'  => 300,
						'step' => 1,
					),
					'%'  => array(
						'min'  => 1,
						'max'  => 100,
						'step' => 1,
					),
				),
				'selectors'  => array(
					'{{WRAPPER}}' => '--wd-brd-radius: {{SIZE}}{{UNIT}};',
				),
				'condition'  => array(
					'rounding_size' => array( 'custom' ),
				),
			)
		);

		$this->add_control(
			'nav_alignment',
			[
				'label'        => esc_html__( 'Alignment', 'cheshalo' ),
				'type'         => 'wd_buttons',
				'options'      => [
					'left'   => [
						'title' => esc_html__( 'Left', 'cheshalo' ),
						'image' => CHESHALO_ASSETS_IMAGES . '/settings/align/left.jpg',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'cheshalo' ),
						'image' => CHESHALO_ASSETS_IMAGES . '/settings/align/center.jpg',
					],
					'right'  => [
						'title' => esc_html__( 'Right', 'cheshalo' ),
						'image' => CHESHALO_ASSETS_IMAGES . '/settings/align/right.jpg',
					],
				],
				'prefix_class' => 'text-',
				'condition'    => [
					'type' => [ 'navigation' ],
				],
			]
		);

		$this->add_control(
			'nav_color_scheme',
			array(
				'label'        => esc_html__( 'Color scheme', 'cheshalo' ),
				'type'         => Controls_Manager::SELECT,
				'options'      => array(
					''       => esc_html__( 'Inherit from Theme Settings', 'cheshalo' ),
					'dark'   => esc_html__( 'Dark', 'cheshalo' ),
					'light'  => esc_html__( 'Light', 'cheshalo' ),
					'custom' => esc_html__( 'Custom', 'cheshalo' ),
				),
				'prefix_class' => 'color-scheme-',
				'default'      => '',
				'render_type'  => 'template',
				'condition'    => [
					'type' => [ 'navigation' ],
				],
			)
		);

		$this->start_controls_tabs(
			'title_text_color_tabs',
			array(
				'condition' => array(
					'type'             => [ 'navigation' ],
					'nav_color_scheme' => 'custom',
				),
			)
		);

		$this->start_controls_tab(
			'title_text_color_tab',
			array(
				'label'     => esc_html__( 'Idle', 'cheshalo' ),
				'condition' => array(
					'type' => [ 'navigation' ],
				),
			)
		);

		$this->add_control(
			'title_text_idle_color',
			array(
				'label'     => esc_html__( 'Color', 'cheshalo' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .wd-nav[class*=wd-style-] > li > a' => 'color: {{VALUE}}',
				),
				'condition' => [
					'type' => [ 'navigation' ],
				],
			)
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'title_text_hover_color_tab',
			array(
				'label'     => esc_html__( 'Hover', 'cheshalo' ),
				'condition' => array(
					'type' => [ 'navigation' ],
				),
			)
		);

		$this->add_control(
			'title_text_hover_color',
			array(
				'label'     => esc_html__( 'Color', 'cheshalo' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .wd-nav[class*=wd-style-] > li:hover > a' => 'color: {{VALUE}}',
				),
				'condition' => [
					'type' => [ 'navigation' ],
				],
			)
		);

		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'title_typography',
				'label'    => esc_html__( 'Title Typography', 'cheshalo' ),
				'selector' => '{{WRAPPER}} div.product-category .wd-entities-title, {{WRAPPER}} .wd-nav-product-cat>li>a',
			)
		);

		$this->end_controls_section();

		/**
		 * Layout settings.
		 */
		$this->start_controls_section(
			'layout_style_section',
			[
				'label'     => esc_html__( 'Layout', 'cheshalo' ),
				'tab'       => Controls_Manager::TAB_STYLE,
				'condition' => [
					'type' => [ 'grid' ],
				],
			]
		);

		$this->add_control(
			'style',
			[
				'label'       => esc_html__( 'Layout', 'cheshalo' ),
				'description' => esc_html__( 'Try out our creative styles for categories block.', 'cheshalo' ),
				'type'        => Controls_Manager::SELECT,
				'default'     => 'default',
				'options'     => array(
					'default'       => esc_html__( 'Default', 'cheshalo' ),
					'masonry'       => esc_html__( 'Masonry', 'cheshalo' ),
					'masonry-first' => esc_html__( 'Masonry (with first wide)', 'cheshalo' ),
					'carousel'      => esc_html__( 'Carousel', 'cheshalo' ),
				),
			]
		);

		$this->add_responsive_control(
			'columns',
			[
				'label'       => esc_html__( 'Columns', 'cheshalo' ),
				'description' => esc_html__( 'Number of columns in the grid.', 'cheshalo' ),
				'type'        => Controls_Manager::SLIDER,
				'default'     => [
					'size' => 4,
				],
				'size_units'  => '',
				'range'       => [
					'px' => [
						'min'  => 1,
						'max'  => 12,
						'step' => 1,
					],
				],
				'condition'   => [
					'style' => [ 'masonry', 'default' ],
				],
			]
		);

		$this->add_control(
			'spacing',
			[
				'label'   => esc_html__( 'Space between', 'cheshalo' ),
				'type'    => Controls_Manager::SELECT,
				'options' => [
					'' => esc_html__( 'Inherit', 'cheshalo' ),
					0  => esc_html__( '0 px', 'cheshalo' ),
					2  => esc_html__( '2 px', 'cheshalo' ),
					6  => esc_html__( '6 px', 'cheshalo' ),
					10 => esc_html__( '10 px', 'cheshalo' ),
					20 => esc_html__( '20 px', 'cheshalo' ),
					30 => esc_html__( '30 px', 'cheshalo' ),
				],
				'default' => '',
			]
		);

		$this->end_controls_section();

		/**
		 * Carousel settings.
		 */
		$this->start_controls_section(
			'carousel_style_section',
			[
				'label'     => esc_html__( 'Carousel', 'cheshalo' ),
				'tab'       => Controls_Manager::TAB_STYLE,
				'condition' => [
					'style' => [ 'carousel' ],
				],
			]
		);

		$this->add_responsive_control(
			'slides_per_view',
			[
				'label'       => esc_html__( 'Slides per view', 'cheshalo' ),
				'description' => esc_html__( 'Set numbers of slides you want to display at the same time on slider\'s container for carousel mode.', 'cheshalo' ),
				'type'        => Controls_Manager::SLIDER,
				'default'     => [
					'size' => 3,
				],
				'size_units'  => '',
				'range'       => [
					'px' => [
						'min'  => 1,
						'max'  => 12,
						'step' => 1,
					],
				],
			]
		);

		$this->add_control(
			'hide_pagination_control',
			[
				'label'        => esc_html__( 'Hide pagination control', 'cheshalo' ),
				'description'  => esc_html__( 'If "YES" pagination control will be removed.', 'cheshalo' ),
				'type'         => Controls_Manager::SWITCHER,
				'default'      => 'no',
				'label_on'     => esc_html__( 'Yes', 'cheshalo' ),
				'label_off'    => esc_html__( 'No', 'cheshalo' ),
				'return_value' => 'yes',
			]
		);

		$this->add_control(
			'hide_prev_next_buttons',
			[
				'label'        => esc_html__( 'Hide prev/next buttons', 'cheshalo' ),
				'description'  => esc_html__( 'If "YES" prev/next control will be removed', 'cheshalo' ),
				'type'         => Controls_Manager::SWITCHER,
				'default'      => 'no',
				'label_on'     => esc_html__( 'Yes', 'cheshalo' ),
				'label_off'    => esc_html__( 'No', 'cheshalo' ),
				'return_value' => 'yes',
			]
		);

		$this->add_control(
			'wrap',
			[
				'label'        => esc_html__( 'Slider loop', 'cheshalo' ),
				'type'         => Controls_Manager::SWITCHER,
				'default'      => 'no',
				'label_on'     => esc_html__( 'Yes', 'cheshalo' ),
				'label_off'    => esc_html__( 'No', 'cheshalo' ),
				'return_value' => 'yes',
			]
		);

		$this->add_control(
			'autoplay',
			[
				'label'        => esc_html__( 'Slider autoplay', 'cheshalo' ),
				'type'         => Controls_Manager::SWITCHER,
				'default'      => 'no',
				'label_on'     => esc_html__( 'Yes', 'cheshalo' ),
				'label_off'    => esc_html__( 'No', 'cheshalo' ),
				'return_value' => 'yes',
			]
		);

		$this->add_control(
			'speed',
			[
				'label'       => esc_html__( 'Slider speed', 'cheshalo' ),
				'description' => esc_html__( 'Duration of animation between slides (in ms)', 'cheshalo' ),
				'default'     => '5000',
				'type'        => Controls_Manager::NUMBER,
				'condition'   => [
					'autoplay' => 'yes',
				],
			]
		);

		$this->add_control(
			'scroll_carousel_init',
			[
				'label'        => esc_html__( 'Init carousel on scroll', 'cheshalo' ),
				'description'  => esc_html__( 'This option allows you to init carousel script only when visitor scroll the page to the slider. Useful for performance optimization.', 'cheshalo' ),
				'type'         => Controls_Manager::SWITCHER,
				'default'      => 'no',
				'label_on'     => esc_html__( 'Yes', 'cheshalo' ),
				'label_off'    => esc_html__( 'No', 'cheshalo' ),
				'return_value' => 'yes',
			]
		);

		$this->end_controls_section();

		/**
		 * Extra settings.
		 */
		$this->start_controls_section(
			'extra_style_section',
			[
				'label' => esc_html__( 'Extra', 'cheshalo' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'lazy_loading',
			[
				'label'        => esc_html__( 'Lazy loading for images', 'cheshalo' ),
				'description'  => esc_html__( 'Enable lazy loading for images for this element.', 'cheshalo' ),
				'type'         => Controls_Manager::SWITCHER,
				'default'      => 'no',
				'label_on'     => esc_html__( 'Yes', 'cheshalo' ),
				'label_off'    => esc_html__( 'No', 'cheshalo' ),
				'return_value' => 'yes',
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		if ( ! cheshalo_woocommerce_installed() ) {
			return;
		}

		$default_settings = [
			// Query.
			'data_source'               => 'custom_query',
			'number'                    => null,
			'orderby'                   => '',
			'order'                     => 'ASC',
			'ids'                       => '',

			'type'                      => 'grid',
			'shop_categories_ancestors' => 'no',
			'show_categories_neighbors' => 'no',
			'images'                    => 'yes',
			'product_count'             => 'yes',
			'mobile_accordion'          => 'on',

			// Layout.
			'columns'                   => array( 'size' => 4 ),
			'columns_tablet'            => array( 'size' => '' ),
			'columns_mobile'            => array( 'size' => '' ),
			'hide_empty'                => 'yes',
			'spacing'                   => cheshalo_get_opt( 'products_spacing' ),
			'style'                     => 'default',

			// Carousel.
			'slides_per_view'           => array( 'size' => 4 ),
			'slides_per_view_tablet'    => array( 'size' => '' ),
			'slides_per_view_mobile'    => array( 'size' => '' ),

			// Design.
			'categories_design'         => cheshalo_get_opt( 'categories_design' ),
			'categories_with_shadow'    => cheshalo_get_opt( 'categories_with_shadow' ),
			'color_scheme'              => cheshalo_get_opt( 'categories_color_scheme' ),

			// Extra.
			'lazy_loading'              => 'no',
			'scroll_carousel_init'      => 'no',
			'custom_sizes'              => apply_filters( 'cheshalo_categories_shortcode_custom_sizes', false ),
		];

		$settings = wp_parse_args( $this->get_settings_for_display(), $default_settings );

		if ( empty( $settings['spacing'] ) && '0' !== $settings['spacing'] && 0 !== $settings['spacing'] ) {
			$settings['spacing'] = cheshalo_get_opt( 'products_spacing' );
		}

		if ( 'inherit' === $settings['color_scheme'] || empty( $settings['color_scheme'] ) ) {
			$settings['color_scheme'] = cheshalo_get_opt( 'categories_color_scheme' );
		}

		// Query.
		$query_args = array(
			'taxonomy'   => 'product_cat',
			'order'      => $settings['order'],
			'hide_empty' => 'yes' === $settings['hide_empty'],
			'include'    => $settings['ids'],
			'pad_counts' => true,
			'number'     => $settings['number'],
		);

		if ( $settings['orderby'] ) {
			$query_args['orderby'] = $settings['orderby'];
		}

		if ( $settings['mobile_accordion'] ) {
			cheshalo_enqueue_inline_style( 'woo-categories-loop-nav-mobile-accordion' );
		}

		if ( 'navigation' === $settings['type'] ) {
			cheshalo_product_categories_nav( $query_args, $settings );
			return;
		}

		if ( 'wc_query' === $settings['data_source'] ) {
			if ( 'yes' !== $settings['hide_empty'] ) {
				add_filter( 'woocommerce_product_subcategories_hide_empty', '__return_false' );
			}
			$categories = woocommerce_get_product_subcategories( is_product_category() ? get_queried_object_id() : 0 );
		} else {
			$categories = get_terms( $query_args );
		}

		if ( ! $categories ) {
			return;
		}

		// Settings.
		if ( 'masonry' === $settings['style'] ) {
			$this->add_render_attribute( 'wrapper', 'class', 'categories-masonry' );
			wp_enqueue_script( 'imagesloaded' );
			cheshalo_enqueue_js_library( 'isotope-bundle' );
			cheshalo_enqueue_js_script( 'shop-masonry' );
		}

		cheshalo_set_loop_prop( 'product_categories_color_scheme', $settings['color_scheme'] );
		cheshalo_set_loop_prop( 'product_categories_is_element', true );
		cheshalo_set_loop_prop( 'products_different_sizes', false );

		if ( ! empty( $settings['img_size'] ) ) {
			cheshalo_set_loop_prop( 'product_categories_image_size', $settings['img_size'] );
		}

		if ( isset( $settings['img_size_custom']['width'] ) && ! empty( $settings['img_size_custom']['width'] ) ) {
			cheshalo_set_loop_prop( 'product_categories_image_size_custom', $settings['img_size_custom'] );
		}

		if ( 'masonry-first' === $settings['style'] ) {
			cheshalo_set_loop_prop( 'products_different_sizes', [ 1 ] );
			$this->add_render_attribute( 'wrapper', 'class', 'categories-masonry' );
			$settings['columns']['size'] = 4;
			wp_enqueue_script( 'imagesloaded' );
			cheshalo_enqueue_js_library( 'isotope-bundle' );
			cheshalo_enqueue_js_script( 'shop-masonry' );
		}

		if ( 'inherit' === $settings['categories_design'] ) {
			$settings['categories_design'] = cheshalo_get_opt( 'categories_design' );
		}

		if ( 'alt' === $settings['categories_design'] && ( ! empty( $settings['image_container_width']['size'] ) || ! empty( $settings['image_container_width_tablet']['size'] ) || ! empty( $settings['image_container_width_mobile']['size'] ) ) ) {
			$this->add_render_attribute( 'wrapper', 'class', 'wd-img-width' );
		}

		$settings['columns'] = isset( $settings['columns']['size'] ) ? $settings['columns']['size'] : 4;

		cheshalo_set_loop_prop( 'product_categories_design', $settings['categories_design'] );
		if ( ! empty( $settings['categories_with_shadow'] ) ) {
			cheshalo_set_loop_prop( 'product_categories_shadow', $settings['categories_with_shadow'] );
		}
		cheshalo_set_loop_prop( 'products_columns', $settings['columns'] );
		cheshalo_set_loop_prop( 'product_categories_style', $settings['style'] );

		if ( isset( $settings['columns_tablet']['size'] ) && $settings['columns_tablet']['size'] ) {
			cheshalo_set_loop_prop( 'products_columns_tablet', $settings['columns_tablet']['size'] );
		}

		if ( isset( $settings['columns_mobile']['size'] ) && $settings['columns_mobile']['size'] ) {
			cheshalo_set_loop_prop( 'products_columns_mobile', $settings['columns_mobile']['size'] );
		}

		// Wrapper classes.
		$this->add_render_attribute(
			[
				'wrapper' => [
					'class' => [
						'products',
						'woocommerce',
						'columns' . $settings['columns'],
						'categories-style-' . $settings['style'],
					],
				],
			]
		);

		// Lazy loading.
		if ( 'yes' === $settings['lazy_loading'] ) {
			cheshalo_lazy_loading_init( true );
			cheshalo_enqueue_inline_style( 'lazy-loading' );
		}

		if ( 'default' === $settings['categories_design'] || 'alt' === $settings['categories_design'] || 'center' === $settings['categories_design'] || 'replace-title' === $settings['categories_design'] ) {
			cheshalo_set_loop_prop( 'old_structure', true );
		}

		if ( 'alt' !== $settings['categories_design'] && 'inherit' !== $settings['categories_design'] ) {
			cheshalo_enqueue_inline_style( 'categories-loop-' . $settings['categories_design'] );
		}

		if ( 'center' === $settings['categories_design'] ) {
			cheshalo_enqueue_inline_style( 'categories-loop-center' );
		}

		if ( 'replace-title' === $settings['categories_design'] ) {
			cheshalo_enqueue_inline_style( 'categories-loop-replace-title' );
		}

		if ( 'mask-subcat' === $settings['categories_design'] ) {
			cheshalo_enqueue_inline_style( 'woo-categories-loop-mask-subcat' );
		}

		if ( 'masonry' === $settings['style'] || 'masonry-first' === $settings['style'] || 'carousel' === $settings['style'] ) {
			cheshalo_enqueue_inline_style( 'woo-categories-loop-layout-masonry' );
		}

		if ( cheshalo_loop_prop( 'old_structure' ) ) {
			cheshalo_enqueue_inline_style( 'categories-loop' );
		} else {
			cheshalo_enqueue_inline_style( 'woo-categories-loop' );
		}

		?>
		<?php if ( $categories ) : ?>
			<?php if ( 'carousel' === $settings['style'] ) : ?>
				<?php
				$carousel_id                 = 'carousel-' . uniqid();
				$settings['carousel_id']     = $carousel_id;
				$settings['post_type']       = 'product';
				$settings['slides_per_view'] = isset( $settings['slides_per_view']['size'] ) ? $settings['slides_per_view']['size'] : 3;

				// Wrapper classes.
				if ( 'yes' === $settings['scroll_carousel_init'] ) {
					cheshalo_enqueue_js_library( 'waypoints' );
					$this->add_render_attribute( 'wrapper', 'class', 'scroll-init' );
				}
				if ( cheshalo_get_opt( 'disable_owl_mobile_devices' ) ) {
					$this->add_render_attribute( 'wrapper', 'class', 'disable-owl-mobile' );
				}
				$this->add_render_attribute( 'wrapper', 'class', 'wd-carousel-spacing-' . $settings['spacing'] );
				$this->add_render_attribute( 'wrapper', 'class', 'categories-style-' . $settings['style'] );
				$this->add_render_attribute( 'wrapper', 'id', $carousel_id );

				if ( ( isset( $settings['slides_per_view_tablet']['size'] ) && ! empty( $settings['slides_per_view_tablet']['size'] ) ) || ( isset( $settings['slides_per_view_mobile']['size'] ) && ! empty( $settings['slides_per_view_mobile']['size'] ) ) ) {
					$settings['custom_sizes'] = array(
						'desktop'          => $settings['slides_per_view'],
						'tablet_landscape' => $settings['slides_per_view_tablet']['size'],
						'tablet'           => $settings['slides_per_view_tablet']['size'],
						'mobile'           => $settings['slides_per_view_mobile']['size'],
					);
				}

				// Owl classes.
				cheshalo_enqueue_inline_style( 'owl-carousel' );
				$this->add_render_attribute(
					[
						'owl' => [
							'class' => [
								'owl-carousel',
								'wd-owl',
								'carousel-items',
								cheshalo_owl_items_per_slide( $settings['slides_per_view'], array(), 'product', false, $settings['custom_sizes'] ),
							],
						],
					]
				);
				?>

				<div <?php echo $this->get_render_attribute_string( 'wrapper' ); // phpcs:ignore ?> <?php echo cheshalo_get_owl_attributes( $settings ); // phpcs:ignore ?>>
					<div <?php echo $this->get_render_attribute_string( 'owl' ); // phpcs:ignore ?>>
						<?php foreach ( $categories as $category ) : ?>
							<?php
							wc_get_template(
								'content-product-cat.php',
								array(
									'category' => $category,
								)
							);
							?>
						<?php endforeach; ?>
					</div>
				</div>
			<?php else : ?>
				<?php
				$this->add_render_attribute( 'wrapper', 'class', 'row' );
				$this->add_render_attribute( 'wrapper', 'class', 'wd-spacing-' . $settings['spacing'] );
				?>

				<div <?php echo $this->get_render_attribute_string( 'wrapper' ); // phpcs:ignore ?>>
					<?php foreach ( $categories as $category ) : ?>
						<?php
						wc_get_template(
							'content-product-cat.php',
							array(
								'category' => $category,
							)
						);
						?>
					<?php endforeach; ?>
				</div>
			<?php endif; ?>
		<?php endif; ?>
		<?php
		cheshalo_reset_loop();
		wc_reset_loop();

		// Lazy loading.
		if ( 'yes' === $settings['lazy_loading'] ) {
			cheshalo_lazy_loading_deinit();
		}
	}
}

Plugin::instance()->widgets_manager->register( new Product_Categories() );
