<?php
/**
 * Add to cart map.
 *
 * @package Cheshalo
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Direct access not allowed.
}

if ( ! function_exists( 'cheshalo_get_vc_map_single_product_add_to_cart' ) ) {
	/**
	 * Content map.
	 */
	function cheshalo_get_vc_map_single_product_add_to_cart() {
		$button_typography = cheshalo_get_typography_map(
			array(
				'key'      => 'button',
				'selector' => '{{WRAPPER}} .single_add_to_cart_button',
			)
		);

		$main_price_typography = cheshalo_get_typography_map(
			array(
				'key'           => 'main_price',
				'selector'      => '{{WRAPPER}} .price',
				'group'         => esc_html__( 'Style', 'cheshalo' ),
				'wd_dependency' => array(
					'element' => 'price_style_tabs',
					'value'   => array( 'main_price' ),
				),
			)
		);

		$old_price_typography = cheshalo_get_typography_map(
			array(
				'key'           => 'old_price',
				'selector'      => '{{WRAPPER}} .price del, {{WRAPPER}} del .amount',
				'group'         => esc_html__( 'Style', 'cheshalo' ),
				'wd_dependency' => array(
					'element' => 'price_style_tabs',
					'value'   => array( 'old_price' ),
				),
			)
		);

		$suffix_typography = cheshalo_get_typography_map(
			array(
				'key'           => 'suffix',
				'selector'      => '{{WRAPPER}} .woocommerce-price-suffix',
				'group'         => esc_html__( 'Style', 'cheshalo' ),
				'wd_dependency' => array(
					'element' => 'price_style_tabs',
					'value'   => array( 'suffix' ),
				),
			)
		);

		return array(
			'base'        => 'cheshalo_single_product_add_to_cart',
			'name'        => esc_html__( 'Product add to cart', 'cheshalo' ),
			'category'    => cheshalo_get_tab_title_category_for_wpb( esc_html__( 'Single product elements', 'cheshalo' ), 'single_product' ),
			'description' => esc_html__( 'Add to cart form and button', 'cheshalo' ),
			'icon'        => CHESHALO_ASSETS . '/images/vc-icon/sp-icons/sp-add-to-cart.svg',
			'params'      => array(
				array(
					'type'       => 'cheshalo_css_id',
					'param_name' => 'cheshalo_css_id',
				),

				array(
					'heading'          => esc_html__( 'Alignment', 'cheshalo' ),
					'type'             => 'wd_select',
					'param_name'       => 'alignment',
					'style'            => 'images',
					'selectors'        => array(),
					'devices'          => array(
						'desktop' => array(
							'value' => 'left',
						),
					),
					'value'            => array(
						esc_html__( 'Left', 'cheshalo' ) => 'left',
						esc_html__( 'Center', 'cheshalo' ) => 'center',
						esc_html__( 'Right', 'cheshalo' ) => 'right',
					),
					'images'           => array(
						'center' => CHESHALO_ASSETS_IMAGES . '/settings/align/center.jpg',
						'left'   => CHESHALO_ASSETS_IMAGES . '/settings/align/left.jpg',
						'right'  => CHESHALO_ASSETS_IMAGES . '/settings/align/right.jpg',
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),

				// Button.
				array(
					'title'      => esc_html__( 'Button', 'cheshalo' ),
					'type'       => 'cheshalo_title_divider',
					'param_name' => 'button_style_divider',
				),

				array(
					'heading'          => esc_html__( 'Design', 'cheshalo' ),
					'type'             => 'dropdown',
					'param_name'       => 'button_design',
					'value'            => array(
						esc_html__( 'Default', 'cheshalo' ) => 'default',
						esc_html__( 'Full width button', 'cheshalo' ) => 'full',
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),

				$button_typography['font_family'],
				$button_typography['font_size'],
				$button_typography['font_weight'],
				$button_typography['text_transform'],
				$button_typography['font_style'],
				$button_typography['line_height'],

				// Variable product.
				array(
					'title'      => esc_html__( 'Variable product', 'cheshalo' ),
					'group'      => esc_html__( 'Style', 'cheshalo' ),
					'type'       => 'cheshalo_title_divider',
					'param_name' => 'variable_product_style_divider',
				),

				array(
					'heading'          => esc_html__( 'Design', 'cheshalo' ),
					'group'            => esc_html__( 'Style', 'cheshalo' ),
					'type'             => 'dropdown',
					'param_name'       => 'design',
					'value'            => array(
						esc_html__( 'Default', 'cheshalo' ) => 'default',
						esc_html__( 'Justify', 'cheshalo' ) => 'justify',
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),

				array(
					'heading'          => esc_html__( 'Swatches layout', 'cheshalo' ),
					'group'            => esc_html__( 'Style', 'cheshalo' ),
					'type'             => 'dropdown',
					'param_name'       => 'swatch_layout',
					'value'            => array(
						esc_html__( 'Default', 'cheshalo' ) => 'default',
						esc_html__( 'Inline', 'cheshalo' ) => 'inline',
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),

				array(
					'heading'          => esc_html__( 'Clear button position', 'cheshalo' ),
					'group'            => esc_html__( 'Style', 'cheshalo' ),
					'type'             => 'wd_select',
					'param_name'       => 'reset_button_position',
					'style'            => 'select',
					'selectors'        => array(),
					'devices'          => array(
						'desktop' => array(
							'value' => 'side',
						),
						'mobile'  => array(
							'value' => 'side',
						),
					),
					'value'            => array(
						esc_html__( 'Side', 'cheshalo' ) => 'side',
						esc_html__( 'Bottom', 'cheshalo' ) => 'bottom',
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),

				array(
					'heading'          => esc_html__( 'Swatch label position', 'cheshalo' ),
					'group'            => esc_html__( 'Style', 'cheshalo' ),
					'type'             => 'wd_select',
					'param_name'       => 'label_position',
					'style'            => 'select',
					'selectors'        => array(),
					'devices'          => array(
						'desktop' => array(
							'value' => 'side',
						),
						'mobile'  => array(
							'value' => 'side',
						),
					),
					'value'            => array(
						esc_html__( 'Side', 'cheshalo' ) => 'side',
						esc_html__( 'Top', 'cheshalo' )  => 'top',
						esc_html__( 'Hide', 'cheshalo' ) => 'hide',
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),

				// Price.
				array(
					'title'      => esc_html__( 'Price', 'cheshalo' ),
					'group'      => esc_html__( 'Style', 'cheshalo' ),
					'type'       => 'cheshalo_title_divider',
					'param_name' => 'price_style_divider',
				),

				array(
					'heading'          => '',
					'group'            => esc_html__( 'Style', 'cheshalo' ),
					'type'             => 'cheshalo_button_set',
					'param_name'       => 'price_style_tabs',
					'tabs'             => true,
					'value'            => array(
						esc_html__( 'Regular price', 'cheshalo' ) => 'main_price',
						esc_html__( 'Old price', 'cheshalo' )  => 'old_price',
						esc_html__( 'Suffix', 'cheshalo' )     => 'suffix',
					),
					'default'          => 'main_price',
					'edit_field_class' => 'vc_col-sm-12 vc_column',
				),

				$main_price_typography['font_family'],
				$main_price_typography['font_size'],
				$main_price_typography['font_weight'],
				$main_price_typography['text_transform'],
				$main_price_typography['font_style'],
				$main_price_typography['line_height'],

				array(
					'heading'          => esc_html__( 'Text color', 'cheshalo' ),
					'group'            => esc_html__( 'Style', 'cheshalo' ),
					'type'             => 'wd_colorpicker',
					'param_name'       => 'main_price_text_color',
					'selectors'        => array(
						'{{WRAPPER}} .price, {{WRAPPER}} .amount, {{WRAPPER}} del' => array(
							'color: {{VALUE}};',
						),
					),
					'wd_dependency'    => array(
						'element' => 'price_style_tabs',
						'value'   => array( 'main_price' ),
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),

				$old_price_typography['font_family'],
				$old_price_typography['font_size'],
				$old_price_typography['font_weight'],
				$old_price_typography['text_transform'],
				$old_price_typography['font_style'],
				$old_price_typography['line_height'],

				array(
					'heading'          => esc_html__( 'Text color', 'cheshalo' ),
					'group'            => esc_html__( 'Style', 'cheshalo' ),
					'type'             => 'wd_colorpicker',
					'param_name'       => 'old_price_text_color',
					'selectors'        => array(
						'{{WRAPPER}} .price del, {{WRAPPER}} del .amount' => array(
							'color: {{VALUE}};',
						),
					),
					'wd_dependency'    => array(
						'element' => 'price_style_tabs',
						'value'   => array( 'old_price' ),
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),

				$suffix_typography['font_family'],
				$suffix_typography['font_size'],
				$suffix_typography['font_weight'],
				$suffix_typography['text_transform'],
				$suffix_typography['font_style'],
				$suffix_typography['line_height'],

				array(
					'heading'          => esc_html__( 'Text color', 'cheshalo' ),
					'group'            => esc_html__( 'Style', 'cheshalo' ),
					'type'             => 'wd_colorpicker',
					'param_name'       => 'suffix_text_color',
					'selectors'        => array(
						'{{WRAPPER}} .woocommerce-price-suffix' => array(
							'color: {{VALUE}};',
						),
					),
					'wd_dependency'    => array(
						'element' => 'price_style_tabs',
						'value'   => array( 'suffix' ),
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),

				// Stock status.
				array(
					'title'      => esc_html__( 'Stock status', 'cheshalo' ),
					'group'      => esc_html__( 'Style', 'cheshalo' ),
					'type'       => 'cheshalo_title_divider',
					'param_name' => 'stock_status_style_divider',
				),

				array(
					'heading'     => esc_html__( 'Enable stock status', 'cheshalo' ),
					'group'       => esc_html__( 'Style', 'cheshalo' ),
					'type'        => 'cheshalo_switch',
					'param_name'  => 'enable_stock_status',
					'hint'        => esc_html__( 'If "NO" stock status will be removed.', 'cheshalo' ),
					'true_state'  => 'yes',
					'false_state' => 'no',
					'default'     => 'yes',
				),

				// Design options.
				array(
					'heading'    => esc_html__( 'CSS box', 'cheshalo' ),
					'group'      => esc_html__( 'Design Options', 'cheshalo' ),
					'type'       => 'css_editor',
					'param_name' => 'css',
				),
				cheshalo_get_vc_responsive_spacing_map(),

				// Width option (with dependency Columns option, responsive).
				cheshalo_get_responsive_dependency_width_map( 'responsive_tabs' ),
				cheshalo_get_responsive_dependency_width_map( 'width_desktop' ),
				cheshalo_get_responsive_dependency_width_map( 'custom_width_desktop' ),
				cheshalo_get_responsive_dependency_width_map( 'width_tablet' ),
				cheshalo_get_responsive_dependency_width_map( 'custom_width_tablet' ),
				cheshalo_get_responsive_dependency_width_map( 'width_mobile' ),
				cheshalo_get_responsive_dependency_width_map( 'custom_width_mobile' ),
			),
		);
	}
}

add_filter( 'vc_autocomplete_cheshalo_single_product_add_to_cart_product_id_callback', 'cheshalo_productIdAutocompleteSuggester_new', 10, 1 );
add_filter( 'vc_autocomplete_cheshalo_single_product_add_to_cart_product_id_render', 'cheshalo_productIdAutocompleteRender', 10, 1 );
